# gazar
A collection of functions to use with GDAL.

Also, the Mongolan word for land, point, place or station (газар).

[![License (3-Clause BSD)](https://img.shields.io/badge/license-BSD%203--Clause-yellow.svg)](https://github.com/snowman2/gazar/blob/master/LICENSE)

[![Build Status](https://travis-ci.org/snowman2/gazar.svg)](https://travis-ci.org/snowman2/gazar)

[![Build status](https://ci.appveyor.com/api/projects/status/49t24ofdg16cl43d?svg=true)](https://ci.appveyor.com/project/snowman2/gazar)

[![Coverage Status](https://coveralls.io/repos/github/snowman2/gazar/badge.svg?branch=master)](https://coveralls.io/github/snowman2/gazar?branch=master)

[![PyPI version](https://badge.fury.io/py/gazar.svg)](https://badge.fury.io/py/gazar)

[![Anaconda-Server Badge](https://anaconda.org/conda-forge/gazar/badges/version.svg)](https://anaconda.org/conda-forge/gazar)

[![Documentation Status](http://readthedocs.org/projects/gazar/badge/?version=latest)](http://gazar.readthedocs.io/en/latest/?badge=latest)

Documentation can be found at: http://gazar.readthedocs.io/en/latest
